==> skpm-1.0.7.tgz: package/lib/index.js <==
#!/usr/bin/env node
'use strict';

var _updateNotifier = require('update-notifier');

var _updateNotifier2 = _interopRequireDefault(_updateNotifier);

var _yargs = require('yargs');

var _yargs2 = _interopRequireDefault(_yargs);

var _create = require('./commands/create');

var _create2 = _interopRequireDefault(_create);

var _log = require('./commands/log');

var _log2 = _interopRequireDefault(_log);

var _login = require('./commands/login');

var _login2 = _interopRequireDefault(_login);

var _logout = require('./commands/logout');

var _logout2 = _interopRequireDefault(_logout);

var _publish = require('./commands/publish');

var _publish2 = _interopRequireDefault(_publish);

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

var _check = require('../check');

var _check2 = _interopRequireDefault(_check);

var _logo = require('./utils/logo');

var _logo2 = _interopRequireDefault(_logo);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

global.Promise = require('bluebird');

(0, _check2.default)();

(0, _updateNotifier2.default)({ pkg: _package2.default }).notify();

_yargs2.default.command(_create2.default).command(_publish2.default).command(_log2.default).command(_login2.default).command(_logout2.default).usage(`${(0, _logo2.default)(`skpm ${_package2.default.version}`)}

For help with a specific command, enter:
  skpm help [command]
`).help().alias('h', 'help').demandCommand().strict().argv;

==> skpm-1.1.1.tgz: package/lib/index.js <==
#!/usr/bin/env node
'use strict';

var _updateNotifier = require('update-notifier');

var _updateNotifier2 = _interopRequireDefault(_updateNotifier);

var _yargs = require('yargs');

var _yargs2 = _interopRequireDefault(_yargs);

var _create = require('./commands/create');

var _create2 = _interopRequireDefault(_create);

var _log = require('./commands/log');

var _log2 = _interopRequireDefault(_log);

var _login = require('./commands/login');

var _login2 = _interopRequireDefault(_login);

var _logout = require('./commands/logout');

var _logout2 = _interopRequireDefault(_logout);

var _publish = require('./commands/publish');

var _publish2 = _interopRequireDefault(_publish);

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

var _check = require('../check');

var _check2 = _interopRequireDefault(_check);

var _logo = require('./utils/logo');

var _logo2 = _interopRequireDefault(_logo);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

global.Promise = require('bluebird');

(0, _check2.default)();

(0, _updateNotifier2.default)({
  pkg: _package2.default,
  isGlobal: true
}).notify();

_yargs2.default.command(_create2.default).command(_publish2.default).command(_log2.default).command(_login2.default).command(_logout2.default).usage(`${(0, _logo2.default)(`skpm ${_package2.default.version}`)}

For help with a specific command, enter:
  skpm help [command]
`).help().alias('h', 'help').demandCommand().strict().argv;
